import javax.swing.*;
import java.awt.event.*;
import java.awt.*;
import com.ibm.as400.access.*;

/*************************************************************************/
/* Class ConfigDialog                                                    */
/* Extension of JDialog that displays Netserver information              */
/*************************************************************************/

public class ConfigDialog extends JDialog implements ActionListener
{
  private AS400 as400;
  private JButton btnName, btnGuest;
  private JPanel pnlButtons;
  private JTable tblConfig;
  private JScrollPane scrConfig;
  private ServerConfigModel model;
  private JDialog dlgName, dlgGuest;
  
  //Boolean to determine if OK button is used.
  private boolean bIsValid = false;
  private boolean bContinue;
  private byte[] serverData = new byte[748];
  private boolean useZLS0201 = false;  //$1.0.1
  
  /***********************************************************************/
  /* public ConfigDialog(Frame owner, String title, boolean modal)       */
  /* Constructor, calls constructor of JDialog, and then adds GUI        */
  /* components.                                                         */
  /***********************************************************************/
  public ConfigDialog(Frame owner, String title, boolean modal, AS400 cnAS400)
  {
    super(owner, title, modal);
    as400 = cnAS400;
    
    pnlButtons = new JPanel();
    pnlButtons.setLayout(new GridLayout(1, 2));
    
    btnName = new JButton("Change Name");
    btnName.addActionListener(this);
    btnGuest = new JButton("Change Guest");
    btnGuest.addActionListener(this);
    
    pnlButtons.add(btnName);
    pnlButtons.add(btnGuest);
        
    //Build table
    model = new ServerConfigModel();
    tblConfig = new JTable(model);
    tblConfig.setPreferredScrollableViewportSize(new Dimension(400, 200));
    scrConfig = new JScrollPane(tblConfig);
    
    getContentPane().add(pnlButtons, BorderLayout.NORTH);
    getContentPane().add(scrConfig, BorderLayout.CENTER);
    pack();

	getRootPane().requestFocus();

	getConfig();
  }
 
  /***********************************************************************/
  /* public void getConfig()                                             */
  /* Create user space and dump information, retrieve.                   */
  /***********************************************************************/
  public void getConfig()
  {
    int rc;
    rc = createSpace();
    if(rc != 0)
    {
        postMessage("Unable to create user space.");
        deleteSpace();
        return;
    }
    
    rc = dumpInformation();
    if(rc != 0)
    {
        postMessage("Unable to retrieve information.");
        deleteSpace();
        return;
    }
    
    readSpace();
    processData();
    deleteSpace();
  }
  
  /***********************************************************************/
  /* private int createSpace()                                           */
  /* Creates the user space on the AS400                                 */
  /***********************************************************************/
  private int createSpace()
  {
    ProgramCall pgm = new ProgramCall(as400);
    ProgramParameter[] parmList = new ProgramParameter[6];
    
    //First parameter - user space to create  length 20
    AS400Text txtCvtr = new AS400Text(20, as400);
    String name = "NETSVRCFG QTEMP     ";
    parmList[0] = new ProgramParameter(txtCvtr.toBytes(name));
    
    //Second parameter - extended attributes  length 10
    AS400Text txtCvtr2 = new AS400Text(10, as400);
    String attr = "          ";
    parmList[1] = new ProgramParameter(txtCvtr2.toBytes(attr));
    
    //Third parameter - intitial length  bin4
    AS400Bin4 intCvtr = new AS400Bin4();
    Integer length = new Integer(2000);
    parmList[2] = new ProgramParameter(intCvtr.toBytes(length));
    
    //Fourth parameter - initial value for all bytes length 1
    AS400Text txtCvtr3 = new AS400Text(1, as400);
    String initial = " ";
    parmList[3] = new ProgramParameter(txtCvtr3.toBytes(initial));
    
    //Fifth parameter - initial public authority
    //Use lenth 10 converter from 2nd parm
    String auth = "*CHANGE   ";
    parmList[4] = new ProgramParameter(txtCvtr2.toBytes(auth));
    
    //Sixth parameter - description
    AS400Text txtCvtr4 = new AS400Text(50, as400);
    String desc = "                                                  "; //50 spaces
    parmList[5] = new ProgramParameter(txtCvtr4.toBytes(desc));
    
    try
    {
        pgm.setProgram(QSYSObjectPathName.toPath("QSYS","QUSCRTUS","PGM"), parmList);
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return -1;
    }
    
    //Run program
    try
    {
        if(pgm.run() != true)
        {
            AS400Message[] messagelist = pgm.getMessageList();
            for (int i = 0; i < messagelist.length; ++i)
            {
                // Show each message.
                postMessage(messagelist[i].getText());
            }
            return -1;
        }
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return -1;
    }
    
    return 0;
  }
  
  /***********************************************************************/
  /* Function private int dumpInformation                                */
  /***********************************************************************/
  private int dumpInformation()
  {
    CommandCall cmdDump = new CommandCall(as400);
    try
    {
        boolean bSuccess = false;
        
        if(useZLS0201)  //$1.0.1
        {
            bSuccess = cmdDump.run("CALL QZLSLSTI PARM('NETSVRCFG QTEMP     ' ZLSL0201 *ALL x'00000000')");
        }
        else  //$1.0.1
        {
            bSuccess = cmdDump.run("CALL QZLSLSTI PARM('NETSVRCFG QTEMP     ' ZLSL0200 *ALL x'00000000')");
        }
        
        if(!bSuccess)
        {
            postMessage("Unable to dump server information.");
            return -1;
        }
        
        //Get messages
        AS400Message[] messagelist = cmdDump.getMessageList();
        for (int i = 0; i < messagelist.length; i++)
        {
            // Show each message
            postMessage(messagelist[i].getText());
        }
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return -1;
    }  
    
    return 0;
  }

  /***********************************************************************/
  /* Function private void deleteSpace                                   */
  /***********************************************************************/
  private void deleteSpace()
  {
    CommandCall cmdDlt = new CommandCall(as400);
    try
    {
        boolean bSuccess = false;
        bSuccess = cmdDlt.run("DLTUSRSPC QTEMP/NETSVRCFG");
        
        if(!bSuccess)
        {
            //Do nothing
        }
    }
    catch(Exception e)
    {
    }  
  }
  
  /***********************************************************************/
  /* Function private void readSpace()                                   */
  /* Retrieve information from User space                                */
  /***********************************************************************/
  private void readSpace()
  {
    AS400Bin4 intCvtr = new AS400Bin4();
    
    ProgramCall pgm = new ProgramCall(as400);
    ProgramParameter[] parmList = new ProgramParameter[4];
    
    //First parameter - user space to retrieve  length 20
    AS400Text txtCvtr = new AS400Text(20, as400);
    String name = "NETSVRCFG QTEMP     ";
    parmList[0] = new ProgramParameter(txtCvtr.toBytes(name));
    
    //Second parameter - starting offset  bin4
    Integer offset = new Integer(125);
    parmList[1] = new ProgramParameter(intCvtr.toBytes(offset));
    
    //Third parameter - length to retrieve  bin4
    Integer length = new Integer(4);
    parmList[2] = new ProgramParameter(intCvtr.toBytes(length));
    
    //Fourth parameter - output
    parmList[3] = new ProgramParameter(4);
    
    try
    {
        pgm.setProgram(QSYSObjectPathName.toPath("QSYS","QUSRTVUS","PGM"), parmList);
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return;
    }
    
    //Run program
    try
    {
        if(pgm.run() != true)
        {
            AS400Message[] messagelist = pgm.getMessageList();
            for (int i = 0; i < messagelist.length; ++i)
            {
                // Show each message.
                postMessage(messagelist[i].getText());
            }
            return;
        }
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return;
    }
    
    int iOffset = intCvtr.toInt(parmList[3].getOutputData());
    iOffset = iOffset + 1;  //Needs to be added for this API
    
    //Now retrieve at Offset
    offset = new Integer(iOffset);
    
    pgm = null;
    parmList = null;

    pgm = new ProgramCall(as400);
    parmList = new ProgramParameter[4];
    
    //First parameter - user space to retrieve  length 20
    parmList[0] = new ProgramParameter(txtCvtr.toBytes(name));
    
    //Second parameter - starting offset  bin4
    parmList[1] = new ProgramParameter(intCvtr.toBytes(offset));
    
    //Third parameter - length to retrieve  bin4
    length = new Integer(748);
    parmList[2] = new ProgramParameter(intCvtr.toBytes(length));
    
    //Fourth parameter - output
    parmList[3] = new ProgramParameter(748);
    
    //Reset program and parm list
    try
    {
        pgm.setProgram(QSYSObjectPathName.toPath("QSYS","QUSRTVUS","PGM"), parmList);
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return;
    }
    
    //Run program
    try
    {
        if(pgm.run() != true)
        {
            AS400Message[] messagelist = pgm.getMessageList();
            for (int i = 0; i < messagelist.length; ++i)
            {
                // Show each message.
                postMessage(messagelist[i].getText());
            }
            return;
        }
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return;
    }
    
    serverData = parmList[3].getOutputData();

  }
  
  /***********************************************************************/
  /* Function private void processData()                                 */
  /* Parse through byte array from readSpace function                    */
  /***********************************************************************/
  private void processData()
  {
    int i;
    byte[] buffer50 = new byte[50];
    byte[] buffer10 = new byte[10];
    byte[] buffer4 = new byte[4];
    byte[] buffer15 = new byte[15];
    byte[] buffer224 = new byte[224];
    String szProp, szCurrent, szPending;
    ServerProperty prop;
    AS400Bin4 intCvtr = new AS400Bin4();
    AS400Text len10cvtr = new AS400Text(10, as400);
    AS400Text len15cvtr = new AS400Text(15, as400);
    AS400Text len50cvtr = new AS400Text(50, as400);
    AS400Text len224cvtr = new AS400Text(224, as400);
    
    //First 8 bytes, current and pending CCSID
    for(i=1; i<=4; i++)
    {
        buffer4[i-1] = serverData[i-1];
    }
    int iCurrent = intCvtr.toInt(buffer4);
    for(i=5; i<=8; i++)
    {
        buffer4[i-5]=serverData[i-1];
    }
    int iPending = intCvtr.toInt(buffer4);
    szProp = "CCSID";
    szCurrent = "" + iCurrent;
    szPending = "" + iPending;
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);
    
    //8 Bytes current and pending Idle Time-Out
    for(i=9; i<=12; i++)
    {
        buffer4[i-9] = serverData[i-1];
    }
    iCurrent = intCvtr.toInt(buffer4);
    for(i=13; i<=16; i++)
    {
        buffer4[i-13]=serverData[i-1];
    }
    iPending = intCvtr.toInt(buffer4);
    szProp = "Idle Time-Out";
    szCurrent = "" + iCurrent;
    szPending = "" + iPending;
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);
    
    //8 Bytes current and pending Opportunistic Lock Time-Out
    for(i=17; i<=20; i++)
    {
        buffer4[i-17] = serverData[i-1];
    }
    iCurrent = intCvtr.toInt(buffer4);
    for(i=21; i<=24; i++)
    {
        buffer4[i-21]=serverData[i-1];
    }
    iPending = intCvtr.toInt(buffer4);
    szProp = "Opportunistic Lock Time-Out";
    szCurrent = "" + iCurrent;
    szPending = "" + iPending;
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);
    
    //8 Bytes current and pending Browse Interval
    for(i=25; i<=28; i++)
    {
        buffer4[i-25] = serverData[i-1];
    }
    iCurrent = intCvtr.toInt(buffer4);
    for(i=29; i<=32; i++)
    {
        buffer4[i-29]=serverData[i-1];
    }
    iPending = intCvtr.toInt(buffer4);
    szProp = "Browsing Interval";
    szCurrent = "" + iCurrent;
    szPending = "" + iPending;
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);
    
    //8 Bytes current and pending WINS support
    for(i=33; i<=36; i++)
    {
        buffer4[i-33]=serverData[i-1];
    }
    iCurrent = intCvtr.toInt(buffer4);
    for(i=37; i<=40; i++)
    {
        buffer4[i-37]=serverData[i-1];
    }
    iPending = intCvtr.toInt(buffer4);
    szProp = "WINS Support";
    if(iCurrent == 1)
    {
        szCurrent = "Use WINS support.";
    }
    else
    {
        szCurrent = "Do not use WINS support.";
    }
    if(iPending == 1)
    {
        szPending = "Use WINS support.";
    }
    else
    {
        szPending = "Do not use WINS support.";
    }
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);
    
    //8 Bytes current and pending guest support
    for(i=41; i<=44; i++)
    {
        buffer4[i-41]=serverData[i-1];
    }
    iCurrent = intCvtr.toInt(buffer4);
    for(i=45; i<=48; i++)
    {
        buffer4[i-45]=serverData[i-1];
    }
    iPending = intCvtr.toInt(buffer4);
    szProp = "Guest Support";
    if(iCurrent == 1)
    {
        szCurrent = "Enabled.";
    }
    else
    {
        szCurrent = "Disabled.";
    }
    if(iPending == 1)
    {
        szPending = "Enabled.";
    }
    else
    {
        szPending = "Disabled.";
    }
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);
    
    //20 Bytes current and pending guest profile
    for(i=49; i<=58; i++)
    {
        buffer10[i-49]=serverData[i-1];        
    }
    removeNulls(buffer10);
    szCurrent = (String)len10cvtr.toObject(buffer10);
    for(i=59; i<=68; i++)
    {
        buffer10[i-59]=serverData[i-1];
    }
    removeNulls(buffer10);
    szPending = (String)len10cvtr.toObject(buffer10);
    szProp = "Guest Profile";
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);
    
    //30 Bytes current and pending server name
    for(i=69; i<=83; i++)
    {
        buffer15[i-69]=serverData[i-1];
    }
    removeNulls(buffer15);
    szCurrent = (String)len15cvtr.toObject(buffer15);
    for(i=84; i<=98; i++)
    {
        buffer15[i-84]=serverData[i-1];
    }
    removeNulls(buffer15);
    szPending = (String)len15cvtr.toObject(buffer15);
    szProp = "Server Name";
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);

    //30 Bytes current and pending domain name
    for(i=99; i<=113; i++)
    {
        buffer15[i-99]=serverData[i-1];
    }
    removeNulls(buffer15);
    szCurrent = (String)len15cvtr.toObject(buffer15);
    for(i=114; i<=128; i++)
    {
        buffer15[i-114]=serverData[i-1];
    }
    removeNulls(buffer15);
    szPending = (String)len15cvtr.toObject(buffer15);
    szProp = "Domain Name";
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);
    
    //100 Bytes current and pending description
    for(i=129; i<=178; i++)
    {
        buffer50[i-129]=serverData[i-1];
    }
    removeNulls(buffer50);
    szCurrent = (String)len50cvtr.toObject(buffer50);
    for(i=179; i<=228; i++)
    {
        buffer50[i-179]=serverData[i-1];
    }
    removeNulls(buffer50);
    szPending = (String)len50cvtr.toObject(buffer50);
    szProp = "Description";
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);
    
    //30 bytes current and pending WINS primary
    for(i=229; i<=243; i++)
    {
        buffer15[i-229]=serverData[i-1];
    }
    removeNulls(buffer15);
    szCurrent = (String)len15cvtr.toObject(buffer15);
    for(i=244; i<=258; i++)
    {
        buffer15[i-244]=serverData[i-1];
    }
    removeNulls(buffer15);
    szPending = (String)len15cvtr.toObject(buffer15);
    szProp = "Primary WINS address";
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);

    //30 bytes current and pending WINS secondary
    for(i=259; i<=273; i++)
    {
        buffer15[i-259]=serverData[i-1];
    }
    removeNulls(buffer15);
    szCurrent = (String)len15cvtr.toObject(buffer15);
    for(i=274; i<=288; i++)
    {
        buffer15[i-274]=serverData[i-1];
    }
    removeNulls(buffer15);
    szPending = (String)len15cvtr.toObject(buffer15);
    szProp = "Secondary WINS address";
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);

    //30 bytes current and pending scope id
    for(i=289; i<=512; i++)
    {
        buffer224[i-289]=serverData[i-1];
    }
    removeNulls(buffer224);
    szCurrent = (String)len224cvtr.toObject(buffer224);
    for(i=513; i<=736; i++)
    {
        buffer224[i-513]=serverData[i-1];
    }
    removeNulls(buffer224);
    szPending = (String)len224cvtr.toObject(buffer224);
    szProp = "Scope ID";
    prop = new ServerProperty(szProp, szCurrent, szPending);
    model.updateProperty(prop);
    
  }
  
  /***********************************************************************/
  /* Function private void postMessage(String msg)                       */
  /***********************************************************************/
  private void postMessage(String msg)
  {
    //Dropped combo box status area for this dialog
    System.out.println(msg);
  }
  
  /***********************************************************************/
  /* function private removeNulls(byte[])                                */
  /* Convert null bytes to spaces                                        */
  /***********************************************************************/
  private void removeNulls(byte[] byteArray)
  {
    int i;
    for(i=1; i<=byteArray.length; i++)
    {
        if(byteArray[i-1]==0)
        {
            byteArray[i-1]=64;
        }
    }
  }

  /***********************************************************************/
  /* private void changeGuest()                                          */
  /***********************************************************************/
  private void changeGuest()
  {
	//Construct a dialog to prompt for share information
	dlgGuest = new JDialog((Dialog)this, "Change Guest Profile", true);
	bContinue = false;
	   
    //Create panels to hold information about new share.
    JPanel pnlGuest = new JPanel();
    JPanel pnlLbl = new JPanel();
    
    pnlGuest.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
    pnlGuest.setLayout(new GridLayout(2,1));
    pnlLbl.setLayout(new GridLayout(2,1));
    
    JLabel lblGuest = new JLabel("Guest Profile");
    JLabel lblBlank = new JLabel("");
    JLabel lblInfo = new JLabel("*NONE to disable.");
    
    JTextField txtGuest = new JTextField(10);
    
    pnlLbl.add(lblGuest);
    pnlGuest.add(txtGuest);
    pnlLbl.add(lblBlank);
    pnlGuest.add(lblInfo);
    
    //Create panel to hold OK button and placeholder label
    JPanel pnlOK = new JPanel();
    pnlOK.setLayout(new GridLayout(1, 2));

    JLabel lblSpace = new JLabel("");
    JButton btnOK = new JButton("OK");
    btnOK.addActionListener(new ActionListener()
      {
	     public void actionPerformed(ActionEvent e)
		  {
		    dlgGuest.hide();
		    bContinue = true;
		  }
	   });

    pnlOK.add(lblSpace);
    pnlOK.add(btnOK);

    dlgGuest.getContentPane().add(pnlGuest, BorderLayout.CENTER);
    dlgGuest.getContentPane().add(pnlOK, BorderLayout.SOUTH);
    dlgGuest.getContentPane().add(pnlLbl, BorderLayout.WEST);

    dlgGuest.pack();
    dlgGuest.setLocation(getLocationOnScreen());
    dlgGuest.setVisible(true);

    //After user hits OK or closes window, execution resumes here.
    if(!bContinue)
    {
      return;  //Stop if OK wasn't clicked.
    }
    
    //Build the command
    CommandCall cmdChangeGuest = new CommandCall(as400);
    String szGuest = txtGuest.getText();
    if(szGuest.equalsIgnoreCase("*NONE"))
    {
        szGuest = "''";
    }
    
    String szCommand = "CALL QZLSCHSG PARM(" + szGuest + " x'00000000')";
    
    try
    {
        boolean bSuccess = false;
                
        bSuccess = cmdChangeGuest.run(szCommand);
        
        if(!bSuccess)
        {
            postMessage("Change guest failed.");
        }
        
        //Get messages
        AS400Message[] messagelist = cmdChangeGuest.getMessageList();
        for (int i = 0; i < messagelist.length; i++)
        {
            // Show each message
            postMessage(messagelist[i].getText());
        }
    }
    catch(Exception e)
    {
        postMessage("Command failed.");
        postMessage(e.getMessage());
    }
  }
  /***********************************************************************/
  /* private void changeName()                                           */
  /***********************************************************************/
  private void changeName()
  {
	//Construct a dialog to prompt for share information
	dlgName = new JDialog((Dialog)this, "Change Server Name", true);
	bContinue = false;
	   
    //Create panels to hold information about new share.
    JPanel pnlName = new JPanel();
    JPanel pnlLbl = new JPanel();
    
    pnlName.setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
    pnlName.setLayout(new GridLayout(3,1));
    pnlLbl.setLayout(new GridLayout(3,1));
    
    JLabel lblServerName = new JLabel("Server Name");
    JLabel lblDomain = new JLabel("Domain");
    JLabel lblDescription = new JLabel("Description");
    
    JTextField txtServerName = new JTextField(15);
    JTextField txtDomain = new JTextField(15);
    JTextField txtDescription = new JTextField(15);
    
    pnlLbl.add(lblServerName);
    pnlName.add(txtServerName);
    pnlLbl.add(lblDomain);
    pnlName.add(txtDomain);
    pnlLbl.add(lblDescription);
    pnlName.add(txtDescription);
    
    //Create panel to hold OK button and placeholder label
    JPanel pnlOK = new JPanel();
    pnlOK.setLayout(new GridLayout(1, 2));

    JLabel lblSpace = new JLabel("");
    JButton btnOK = new JButton("OK");
    btnOK.addActionListener(new ActionListener()
      {
	     public void actionPerformed(ActionEvent e)
		  {
		    dlgName.hide();
		    bContinue = true;
		  }
	   });

    pnlOK.add(lblSpace);
    pnlOK.add(btnOK);

    dlgName.getContentPane().add(pnlName, BorderLayout.CENTER);
    dlgName.getContentPane().add(pnlOK, BorderLayout.SOUTH);
    dlgName.getContentPane().add(pnlLbl, BorderLayout.WEST);

    dlgName.pack();
    dlgName.setLocation(getLocationOnScreen());
    dlgName.setVisible(true);

    //After user hits OK or closes window, execution resumes here.
    if(!bContinue)
    {
      return;  //Stop if OK wasn't clicked.
    }
    
    //Build the command
    CommandCall cmdChangeName = new CommandCall(as400);
    String szServer = txtServerName.getText();
    String szDomain = txtDomain.getText();
    String szDescription = txtDescription.getText();
    
    
    String szCommand = "CALL QZLSCHSN PARM(" + szServer + " '" + szDomain + "' '" +
                                           szDescription + "' x'00000000')";
    
    try
    {
        boolean bSuccess = false;
                
        bSuccess = cmdChangeName.run(szCommand);
        
        if(!bSuccess)
        {
            postMessage("Change server name failed.");
        }
        
        //Get messages
        AS400Message[] messagelist = cmdChangeName.getMessageList();
        for (int i = 0; i < messagelist.length; i++)
        {
            // Show each message
            postMessage(messagelist[i].getText());
        }
    }
    catch(Exception e)
    {
        postMessage("Command failed.");
        postMessage(e.getMessage());
    }    
  }
 
  /***********************************************************************/
  /* private void getHostLevel()                                         */
  /* $1.0.1                                                              */
  /* Added 10/11/01 to support R430/R420 OS400                           */
  /***********************************************************************/
  private void getHostLevel()
  {
    int version = 0;
    int release = 0;
    
    try
    {
        version = as400.getVersion();
        release = as400.getRelease();
    }
    catch(Exception e)
    {
        useZLS0201 = false;
        return;
    }
    
    if(version >= 5)
    {
        useZLS0201 = true;
        return;
    }
    else
    {
        if(version == 4)
        {
            if(release >= 4)
            {
                useZLS0201 = true;
            }
            else
            {
                useZLS0201 = false;
            }
        }
        else
        {
            useZLS0201 = false;
        }
        return;
    }
  }
        
  /***********************************************************************/
  /* public void actionPerformed(ActionEvent e)                          */
  /* Required method of ActionListener interface                         */
  /***********************************************************************/
  public void actionPerformed(ActionEvent e)
  {
    if(e.getSource()==btnName)
    {
        changeName();
        model.clear();
        getConfig();
    }
    if(e.getSource()==btnGuest)
    {
        changeGuest();
        model.clear();
        getConfig();
    }
  }

}