import javax.swing.*;
import javax.swing.event.*;
import java.awt.event.*;
import java.awt.*;
import com.ibm.as400.access.*;

/*************************************************************************/
/*  Class NetSvrCfg                                                      */
/*************************************************************************/

public class NetSvrCfg implements ActionListener
{
  //Boolean to track connected status
  private boolean bConnected;
  
  //Private GUI objects
  private JFrame frmMain;
  private JComboBox cbStatus;
  private JTextField txtSystem;
  private JLabel lblSystem;
  private JButton btnConnect, btnDisconnect, btnStart, btnStop, btnConfig, btnShares;
  private JPanel pnlMain, pnlTop;

  //Private Toolkit objects
  private AS400 as400;

  /***********************************************************************/
  /*  public NetSvrCfg()                                                 */
  /*  Constructor for NetSvrCfg, sets up the GUI Interface               */
  /***********************************************************************/
  public NetSvrCfg()
  {
    //Initialize member variables
    bConnected = false;
    
    //Create main frame
    frmMain = new JFrame("Netserver Configuration (Version 1.0.1)");
    //Create panels
    pnlMain = new JPanel(new GridLayout(2,2));
    pnlMain.setBorder(BorderFactory.createEtchedBorder());
    pnlTop = new JPanel(new GridLayout(2,2));
    
    //Create connection status box.
    cbStatus = new JComboBox();
    cbStatus.setEditable(false);
    
    //Create text fields.
    txtSystem = new JTextField(15);
    //Create buttons
    btnConnect = new JButton("Connect");
    btnConnect.addActionListener(this);
    btnDisconnect = new JButton("Disconnect");
    btnDisconnect.addActionListener(this);
    btnStart = new JButton("Start Server");
    btnStart.addActionListener(this);
    btnStop = new JButton("Stop Server");
    btnStop.addActionListener(this);
    btnConfig = new JButton("Configuration");
    btnConfig.addActionListener(this);
    btnShares = new JButton("File Shares");
    btnShares.addActionListener(this);
    
    //Create labels
    lblSystem = new JLabel("System:     ");
    lblSystem.setHorizontalAlignment(JLabel.RIGHT);
    
    //Add items to panels
    pnlTop.add(lblSystem);
    pnlTop.add(txtSystem);
    pnlTop.add(btnConnect);
    pnlTop.add(btnDisconnect);
    
    pnlMain.add(btnStart);
    pnlMain.add(btnStop);
    pnlMain.add(btnConfig);
    pnlMain.add(btnShares);
    
    //Add items to main frame
    frmMain.getContentPane().add(pnlTop, BorderLayout.NORTH);
    frmMain.getContentPane().add(pnlMain, BorderLayout.CENTER);        
    frmMain.getContentPane().add(cbStatus, BorderLayout.SOUTH);
    
    frmMain.pack();
    frmMain.setVisible(true);
    
    //Display disconnected message
    postMessage("Disconnected.");
    
    //Disable inappropriate controls
    enableControls();
    
	//Handle window closing
    frmMain.addWindowListener(new WindowAdapter() 
	 {
      public void windowClosing(WindowEvent evt) 
		{
		  shutdown();
      }
    });
  }

  /***********************************************************************/
  /* Function void shutdown()                                            */
  /***********************************************************************/
  public void shutdown()
  {
    System.exit(0);
  }

  /***********************************************************************/
  /* Function public void actionPerformed(ActionEvent e)                 */
  /* Required method of ActionListener interface                         */
  /***********************************************************************/
  public void actionPerformed(ActionEvent e)
  {
    if(e.getSource()==btnConnect)
    {
        connectSystem(txtSystem.getText());
    }
    if(e.getSource()==btnDisconnect)
    {
        disconnectSystem();
    }
    if(e.getSource()==btnStart)
    {
        startServer();
    }
    if(e.getSource()==btnStop)
    {
        stopServer();
    }
    if(e.getSource()==btnConfig)
    {
        configServer();
    }
    if(e.getSource()==btnShares)
    {
        configShares();
    }
  }

  /***********************************************************************/
  /* Function private void enableControls()                              */
  /***********************************************************************/
  private void enableControls()
  {
    btnConnect.setEnabled(!bConnected);
    btnDisconnect.setEnabled(bConnected);
    btnStart.setEnabled(bConnected);
    btnStop.setEnabled(bConnected);
    btnConfig.setEnabled(bConnected);
    btnShares.setEnabled(bConnected);
  }
  
  /***********************************************************************/
  /* Function private void postMessage(String msg)                       */
  /***********************************************************************/
  private void postMessage(String msg)
  {
    cbStatus.addItem(msg);
    cbStatus.setSelectedItem(msg);
  }
  
  /***********************************************************************/
  /* Function private void connectSystem(String sysName)                 */
  /***********************************************************************/
  private void connectSystem(String sysName)
  {
    as400 = new AS400(sysName);
    
    try
    {
        as400.connectService(AS400.COMMAND);
    }
    catch(Exception e)
    {
        postMessage("Connect failed.");
        as400 = null;
        return;
    }
    
    bConnected = true;
    enableControls();
    
    postMessage("Connected to " + as400.getSystemName() + ".");
    txtSystem.setText(as400.getSystemName());
  }
  
  /***********************************************************************/
  /* Function private void disconnectSystem()                            */
  /***********************************************************************/
  private void disconnectSystem()
  {
    as400.disconnectAllServices();
    as400 = null;
    
    bConnected = false;
    enableControls();
    postMessage("Disconnected.");
  }

  /***********************************************************************/
  /* Function private void startServer()                                 */
  /***********************************************************************/
  private void startServer()
  {
    CommandCall cmdStart = new CommandCall(as400);
    try
    {
        boolean bSuccess = false;
        bSuccess = cmdStart.run("CALL QZLSSTRS PARM('0' x'00000000')");
        
        if(!bSuccess)
        {
            postMessage("Command failed.");
        }
        else
        {
            postMessage("Netserver started.");
        }
        
        //Get messages
        AS400Message[] messagelist = cmdStart.getMessageList();
        for (int i = 0; i < messagelist.length; i++)
        {
            // Show each message
            postMessage(messagelist[i].getText());
        }
    }
    catch(Exception e)
    {
        postMessage("Command failed.");
        postMessage(e.getMessage());
    }
  }

  /***********************************************************************/
  /* Function private void stopServer()                                  */
  /***********************************************************************/
  private void stopServer()
  {
    CommandCall cmdStop = new CommandCall(as400);
    try
    {
        boolean bSuccess = false;
        bSuccess = cmdStop.run("CALL QZLSENDS PARM(x'00000000')");
        
        if(!bSuccess)
        {
            postMessage("Command failed.");
        }
        else
        {
            postMessage("Netserver ended.");
        }
        
        //Get messages
        AS400Message[] messagelist = cmdStop.getMessageList();
        for (int i = 0; i < messagelist.length; i++)
        {
            // Show each message
            postMessage(messagelist[i].getText());
        }
    }
    catch(Exception e)
    {
        postMessage("Command failed.");
        postMessage(e.getMessage());
    }
  }

  /***********************************************************************/
  /* Function private void configServer()                                */
  /***********************************************************************/
  private void configServer()
  {
    ConfigDialog cfgDlg = new ConfigDialog(frmMain, "Configuration", false, as400);
    cfgDlg.setLocation(frmMain.getLocationOnScreen());
    cfgDlg.setVisible(true);
  }
  
  /***********************************************************************/
  /* Function private void configShares()                                */
  /***********************************************************************/
  private void configShares()
  {
    ShareDialog shrDlg = new ShareDialog(frmMain, "File Shares", false, as400);
    shrDlg.setLocation(frmMain.getLocationOnScreen());
    shrDlg.setVisible(true);
  }  
  
  /***********************************************************************/
  /* Function public static void main(String args[])                     */
  /* Main method, where application starts                               */
  /***********************************************************************/
  public static void main(String[] args)
  {
    NetSvrCfg app = new NetSvrCfg();
  }

}

