import javax.swing.table.*;
import java.util.Vector;

class ServerConfigModel extends AbstractTableModel 
{
    protected static int NUM_COLUMNS = 3;
    protected static int START_NUM_ROWS = 5;
    protected int nextEmptyRow = 0;
    protected int numRows = 0;

    static final public String szProp = "PROPERTY";
    static final public String szCurrent = "CURRENT";
    static final public String szPending = "PENDING";

    protected Vector data = null;

    public ServerConfigModel() 
    {
        data = new Vector();
    }

    public String getColumnName(int column) 
    {
	switch (column)
	{
	  case 0:
	    return szProp;
	  case 1:
	    return szCurrent;
	  case 2:
	    return szPending;
	}
	return "";
    }

    public int getColumnCount() {
        return NUM_COLUMNS;
    }

    public int getRowCount() {
        if (numRows < START_NUM_ROWS) {
            return START_NUM_ROWS;
        } else {
            return numRows;
        }
    }

    public synchronized Object getValueAt(int row, int column) {
	try 
	{
	    ServerProperty prop = (ServerProperty)data.elementAt(row);
        switch (column) 
        {
            case 0:
                return prop.szProp;
            case 1:
                return prop.szCurrent;
            case 2:
                return prop.szPending;
        }    
	} 
	catch (Exception e) 
	{
	}
	return "";
    }

    public void updateProperty(ServerProperty prop)
    {
        ServerProperty p = null;
        int index = -1; 
        boolean found = false;
	    boolean addedRow = false;
        
        int i = 0;
        while (!found && (i < nextEmptyRow)) 
        {
            p = (ServerProperty)data.elementAt(i);
            if (p.szProp == prop.szProp) 
            {
                found = true;
                index = i;
            } 
            else
            {
                i++;
            }
        }

        if (found) 
        { //update old property
	        data.setElementAt(prop, index);
        } 
        else 
        { //add property
	        if (numRows <= nextEmptyRow) 
	        {
		        //add a row
                numRows++;
		        addedRow = true;
            }
            index = nextEmptyRow;
	        data.addElement(prop);
	    }
    
        nextEmptyRow++;

	    //Notify listeners that the data changed.
	    if (addedRow) 
	    {
	        fireTableRowsInserted(index, index);
	    } 
	    else 
	    {
	        fireTableRowsUpdated(index, index);
	    }
    }

    public synchronized void clear() 
    {
	    int oldNumRows = numRows;

        numRows = START_NUM_ROWS;
	    data.removeAllElements();
        nextEmptyRow = 0;

	    if (oldNumRows > START_NUM_ROWS) 
	    {
    	    fireTableRowsDeleted(START_NUM_ROWS, oldNumRows - 1);
	    }
	
	    fireTableRowsUpdated(0, START_NUM_ROWS - 1);
    }
}
