import javax.swing.*;
import javax.swing.event.*;
import java.awt.event.*;
import java.awt.*;
import com.ibm.as400.access.*;

/*************************************************************************/
/* Class ShareDialog                                                     */
/* Extension of JDialog that displays Netserver information              */
/*************************************************************************/

public class ShareDialog extends JDialog implements ActionListener
{
  private AS400 as400;
  private JButton btnAdd, btnDelete;
  private JDialog dlgAdd;
  private JPanel pnlButtons;
  private JTable tblShares;
  private JScrollPane scrShares;
  private ShareListModel model;
  private int iSelected;
  private boolean bContinue;
  
  /***********************************************************************/
  /* public ShareDialog(Frame owner, String title, boolean modal)        */
  /* Constructor, calls constructor of JDialog, and then adds GUI        */
  /* components.                                                         */
  /***********************************************************************/
  public ShareDialog(Frame owner, String title, boolean modal, AS400 cnAS400)
  {
    super(owner, title, modal);
    as400 = cnAS400;
    
    pnlButtons = new JPanel();
    pnlButtons.setLayout(new GridLayout(1, 2));
    
    btnAdd = new JButton("Add Share");
    btnAdd.addActionListener(this);
    
    btnDelete = new JButton("Delete Share");
    btnDelete.addActionListener(this);
    
    pnlButtons.add(btnAdd);
    pnlButtons.add(btnDelete);
        
    //Build table
    model = new ShareListModel();
    tblShares = new JTable(model);
    tblShares.setPreferredScrollableViewportSize(new Dimension(400, 200));
    tblShares.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
    scrShares = new JScrollPane(tblShares);
    
    //Add selection listening to table
    ListSelectionModel rowSM = tblShares.getSelectionModel();
    rowSM.addListSelectionListener(new ListSelectionListener() 
    {
        public void valueChanged(ListSelectionEvent e) 
        {
            if (e.getValueIsAdjusting()) return;
        
            ListSelectionModel lsm = (ListSelectionModel)e.getSource();
            if (lsm.isSelectionEmpty()) 
            {
                iSelected = -1;
            } 
            else 
            {
                iSelected = lsm.getMinSelectionIndex();
            }
        }
    });

    getContentPane().add(pnlButtons, BorderLayout.NORTH);
    getContentPane().add(scrShares, BorderLayout.CENTER);
    pack();

	getRootPane().requestFocus();

	getShares();
	
	iSelected = -1;
  }
 
  /***********************************************************************/
  /* private void getShares()                                            */
  /* Create user space and dump information, retrieve.                   */
  /***********************************************************************/
  private void getShares()
  {
    int rc;
    rc = createSpace();
    if(rc != 0)
    {
        postMessage("Unable to create user space.");
        deleteSpace();
        return;
    }
    
    rc = dumpInformation();
    if(rc != 0)
    {
        postMessage("Unable to retrieve information.");
        deleteSpace();
        return;
    }
    
    processSpace();
    deleteSpace();
  }
  
  /***********************************************************************/
  /* private int createSpace()                                           */
  /* Creates the user space on the AS400                                 */
  /***********************************************************************/
  private int createSpace()
  {
    ProgramCall pgm = new ProgramCall(as400);
    ProgramParameter[] parmList = new ProgramParameter[6];
    
    //First parameter - user space to create  length 20
    AS400Text txtCvtr = new AS400Text(20, as400);
    String name = "NETSVRSHR QTEMP     ";
    parmList[0] = new ProgramParameter(txtCvtr.toBytes(name));
    
    //Second parameter - extended attributes  length 10
    AS400Text txtCvtr2 = new AS400Text(10, as400);
    String attr = "          ";
    parmList[1] = new ProgramParameter(txtCvtr2.toBytes(attr));
    
    //Third parameter - intitial length  bin4
    AS400Bin4 intCvtr = new AS400Bin4();
    Integer length = new Integer(2000);
    parmList[2] = new ProgramParameter(intCvtr.toBytes(length));
    
    //Fourth parameter - initial value for all bytes length 1
    AS400Text txtCvtr3 = new AS400Text(1, as400);
    String initial = " ";
    parmList[3] = new ProgramParameter(txtCvtr3.toBytes(initial));
    
    //Fifth parameter - initial public authority
    //Use lenth 10 converter from 2nd parm
    String auth = "*CHANGE   ";
    parmList[4] = new ProgramParameter(txtCvtr2.toBytes(auth));
    
    //Sixth parameter - description
    AS400Text txtCvtr4 = new AS400Text(50, as400);
    String desc = "                                                  "; //50 spaces
    parmList[5] = new ProgramParameter(txtCvtr4.toBytes(desc));
    
    try
    {
        pgm.setProgram(QSYSObjectPathName.toPath("QSYS","QUSCRTUS","PGM"), parmList);
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return -1;
    }
    
    //Run program
    try
    {
        if(pgm.run() != true)
        {
            AS400Message[] messagelist = pgm.getMessageList();
            for (int i = 0; i < messagelist.length; ++i)
            {
                // Show each message.
                postMessage(messagelist[i].getText());
            }
            return -1;
        }
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return -1;
    }
    
    return 0;
  }
  
  /***********************************************************************/
  /* Function private int dumpInformation                                */
  /***********************************************************************/
  private int dumpInformation()
  {
    CommandCall cmdDump = new CommandCall(as400);
    try
    {
        boolean bSuccess = false;
        bSuccess = cmdDump.run("CALL QZLSLSTI PARM('NETSVRSHR QTEMP     ' ZLSL0100 *ALL x'00000000')");
        
        if(!bSuccess)
        {
            postMessage("Unable to dump server information.");
            return -1;
        }
        
        //Get messages
        AS400Message[] messagelist = cmdDump.getMessageList();
        for (int i = 0; i < messagelist.length; i++)
        {
            // Show each message
            postMessage(messagelist[i].getText());
        }
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return -1;
    }  
    
    return 0;
  }

  /***********************************************************************/
  /* Function private void deleteSpace                                   */
  /***********************************************************************/
  private void deleteSpace()
  {
    CommandCall cmdDlt = new CommandCall(as400);
    try
    {
        boolean bSuccess = false;
        bSuccess = cmdDlt.run("DLTUSRSPC QTEMP/NETSVRSHR");
        
        if(!bSuccess)
        {
            //Do nothing
        }
    }
    catch(Exception e)
    {
    }  
  }
    
  /***********************************************************************/
  /* Function private void processSpace()                                */
  /* Parse through user space                                            */
  /***********************************************************************/
  private void processSpace()
  {
    int iOffset;
    int iNumShares;
    int iRecLength;
    AS400Bin4 intCvtr = new AS400Bin4();
    AS400Text len12cvtr = new AS400Text(12, as400);
    
    ProgramCall pgm = new ProgramCall(as400);
    ProgramParameter[] parmList = new ProgramParameter[4];
    
    //First parameter - user space to retrieve  length 20
    AS400Text txtCvtr = new AS400Text(20, as400);
    String name = "NETSVRSHR QTEMP     ";
    parmList[0] = new ProgramParameter(txtCvtr.toBytes(name));
    
    //Second parameter - starting offset  bin4
    Integer offset = new Integer(125);
    parmList[1] = new ProgramParameter(intCvtr.toBytes(offset));
    
    //Third parameter - length to retrieve  bin4
    Integer length = new Integer(4);
    parmList[2] = new ProgramParameter(intCvtr.toBytes(length));
    
    //Fourth parameter - output
    parmList[3] = new ProgramParameter(4);
    
    try
    {
        pgm.setProgram(QSYSObjectPathName.toPath("QSYS","QUSRTVUS","PGM"), parmList);
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return;
    }
    
    //Run program
    try
    {
        if(pgm.run() != true)
        {
            AS400Message[] messagelist = pgm.getMessageList();
            for (int i = 0; i < messagelist.length; ++i)
            {
                // Show each message.
                postMessage(messagelist[i].getText());
            }
            return;
        }
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return;
    }
    
    iOffset = intCvtr.toInt(parmList[3].getOutputData());
    iOffset = iOffset + 1;  //Needs to be added for this API
    
    //Update parameter list to retrieve number of shares at offset of 0x84
    offset = new Integer(133);
    parmList[1] = new ProgramParameter(intCvtr.toBytes(offset));

    //Run program
    try
    {
        if(pgm.run() != true)
        {
            AS400Message[] messagelist = pgm.getMessageList();
            for (int i = 0; i < messagelist.length; ++i)
            {
                // Show each message.
                postMessage(messagelist[i].getText());
            }
            return;
        }
    }
    catch(Exception e)
    {
        postMessage(e.getMessage());
        return;
    }
    
    iNumShares = intCvtr.toInt(parmList[3].getOutputData());
    
    //Loop through shares.
    for(int i=1; i<= iNumShares; i++)
    {
        String szShare, szPath, szAccess;
        int iAccess;
        int iDevice;
        AS400Text lenvarcvtr;
        
        byte[] data;
        byte[] share = new byte[12];
        byte[] path;
        byte[] access = new byte[4];
        byte[] device = new byte[4];
        
        //Update to retrieve at offset, first 4 bytes are record length
        offset = new Integer(iOffset);
        parmList[1] = new ProgramParameter(intCvtr.toBytes(offset));
        
        //Run program
        try
        {
            if(pgm.run() != true)
            {
                AS400Message[] messagelist = pgm.getMessageList();
                for (int j = 0; j < messagelist.length; ++j)
                {
                    // Show each message.
                    postMessage(messagelist[i].getText());
                }
                return;
            }
        }
        catch(Exception e)
        {
            postMessage(e.getMessage());
            return;
        }
    
        iRecLength = intCvtr.toInt(parmList[3].getOutputData());
        
        //Update parameters to adjust for correct length, retrieve at same location
        length = new Integer(iRecLength);
        parmList[2] = new ProgramParameter(intCvtr.toBytes(length));
        parmList[3] = new ProgramParameter(iRecLength);

        //Run program
        try
        {
            if(pgm.run() != true)
            {
                AS400Message[] messagelist = pgm.getMessageList();
                for (int j = 0; j < messagelist.length; ++j)
                {
                    // Show each message.
                    postMessage(messagelist[i].getText());
                }
                return;
            }
        }
        catch(Exception e)
        {
            postMessage(e.getMessage());
            return;
        }
        
        data = parmList[3].getOutputData();
        
        //get share name
        for(int j=1; j<=12; j++)
        {
            share[j-1] = data[j+3];
        }
        removeNulls(share);
        szShare = (String)len12cvtr.toObject(share);
        
        //get device type
        for(int j=1; j<=4; j++)
        {
            device[j-1] = data[j+15];
        }
        iDevice = intCvtr.toInt(device);
        
        //get Access mode
        for(int j=1; j<=4; j++)
        {
            access[j-1] = data[j+19];
        }
        iAccess = intCvtr.toInt(access);
        if(iAccess==1)
        {
            szAccess="Read Only";
        }
        else
        {
            szAccess="Read/Write";
        }
        
        //Get path name
        path = new byte[iRecLength - 164];
        for(int j=164; j<iRecLength; j++)
        {
            path[j-164] = data[j];
        }
        removeNulls(path);
        lenvarcvtr = new AS400Text(iRecLength-164, as400);
        szPath = (String)lenvarcvtr.toObject(path);
        
        if(iDevice==0)
        {
            FileShare fs = new FileShare(szShare, szPath.trim(), szAccess);
            model.updateShare(fs);
        }
        
        //Increment offset by current record length
        iOffset = iOffset + iRecLength;
    }
  }
  
  /***********************************************************************/
  /* Function private void postMessage(String msg)                       */
  /***********************************************************************/
  private void postMessage(String msg)
  {
    //Dropped combo box status area for this dialog
    System.out.println(msg);
  }
  
  /***********************************************************************/
  /* function private void deleteShare()                                 */
  /***********************************************************************/
  private void deleteShare()
  {
    CommandCall cmdDltShr = new CommandCall(as400);
    
    if(iSelected==-1)
    {
        //End if no share selected
        return;
    }
    
    try
    {
        boolean bSuccess = false;
        String szShareToRemove;
        String szCommand;
        
        szShareToRemove = (String)model.getValueAt(iSelected, 0);
        
        int iContinue = JOptionPane.showConfirmDialog(this, "Confirm delete for " + szShareToRemove);
        if(iContinue!=JOptionPane.YES_OPTION)
        {
            //Stop if not confirmed
            return;
        }
        
        szCommand = "CALL QZLSRMS PARM(" + szShareToRemove.trim() + " x'00000000')";
        
        bSuccess = cmdDltShr.run(szCommand);
        
        if(!bSuccess)
        {
            postMessage("Delete failed.");
        }
        
        //Get messages
        AS400Message[] messagelist = cmdDltShr.getMessageList();
        for (int i = 0; i < messagelist.length; i++)
        {
            // Show each message
            postMessage(messagelist[i].getText());
        }
    }
    catch(Exception e)
    {
        postMessage("Command failed.");
        postMessage(e.getMessage());
    }
  }

  /***********************************************************************/
  /* function private addShare()                                         */
  /* Prompts for user input and creates file share                       */
  /***********************************************************************/
  private void addShare()
  {
	//Construct a dialog to prompt for share information
	dlgAdd = new JDialog((Dialog)this, "Add File Share", true);
	bContinue = false;
	   
    //Create panel to hold information about new share.
    JPanel pnlAdd = new JPanel();
    JPanel pnlLbl = new JPanel();
    
    pnlAdd.setBorder(BorderFactory.createEmptyBorder(10, 10, 10, 10));
    pnlAdd.setLayout(new GridLayout(4,1));
    pnlLbl.setLayout(new GridLayout(4,1));
    
    JLabel lblShareName = new JLabel("Share Name");
    JLabel lblShareDesc = new JLabel("Description");
    JLabel lblSharePath = new JLabel("Path");
    JLabel lblShareAccess = new JLabel("Access");
    
    JTextField txtName = new JTextField(25);
    JTextField txtPath = new JTextField(25);
    JTextField txtDescription = new JTextField(25);
    Object[] options = {"Read Only", "Read/Write"};
    JComboBox cmbAccess = new JComboBox(options);
    
    pnlLbl.add(lblShareName);
    pnlAdd.add(txtName);
    pnlLbl.add(lblShareDesc);
    pnlAdd.add(txtDescription);
    pnlLbl.add(lblShareAccess);
    pnlAdd.add(cmbAccess);
    pnlLbl.add(lblSharePath);
    pnlAdd.add(txtPath);
    
    //Create panel to hold OK button and placeholder label
    JPanel pnlOK = new JPanel();
    pnlOK.setLayout(new GridLayout(1, 2));

    JLabel lblSpace = new JLabel("");
    JButton btnOK = new JButton("OK");
    btnOK.addActionListener(new ActionListener()
      {
	     public void actionPerformed(ActionEvent e)
		  {
		    dlgAdd.hide();
		    bContinue = true;
		  }
	   });

    pnlOK.add(lblSpace);
    pnlOK.add(btnOK);

    dlgAdd.getContentPane().add(pnlAdd, BorderLayout.CENTER);
    dlgAdd.getContentPane().add(pnlOK, BorderLayout.SOUTH);
    dlgAdd.getContentPane().add(pnlLbl, BorderLayout.WEST);

    dlgAdd.pack();
    dlgAdd.setLocation(getLocationOnScreen());
    dlgAdd.setVisible(true);

    //After user hits OK or closes window, execution resumes here.
    if(!bContinue)
    {
      return;  //Stop if OK wasn't clicked.
    }
    
    //Build the command
    CommandCall cmdAddShare = new CommandCall(as400);
    String szShare = txtName.getText();
    String szPath = txtPath.getText();
    String szDescription = txtDescription.getText();
    String szTemp = (String)cmbAccess.getSelectedItem();
    String szAccess;
    if(szTemp.equals("Read Only"))
    {
        szAccess="x'00000001'";
    }
    else
    {
        szAccess="x'00000002'";
    }
    
    //Build length parameter
    StringBuffer sbPathLength = new StringBuffer(Integer.toHexString(szPath.length()));
    while(sbPathLength.length() < 8)
    {
        sbPathLength.insert(0, "0");
    }
    
    String szCommand = "CALL QZLSADFS PARM(" + szShare + " '"
                                      + szPath + "' x'"
                                      + sbPathLength.toString() + "' x'00000000' '"
                                      + szDescription + "' "
                                      + szAccess + " x'FFFFFFFF' x'00000000')";
                                      
    try
    {
        boolean bSuccess = false;
                
        bSuccess = cmdAddShare.run(szCommand);
        
        if(!bSuccess)
        {
            postMessage("Add share failed.");
        }
        
        //Get messages
        AS400Message[] messagelist = cmdAddShare.getMessageList();
        for (int i = 0; i < messagelist.length; i++)
        {
            // Show each message
            postMessage(messagelist[i].getText());
        }
    }
    catch(Exception e)
    {
        postMessage("Command failed.");
        postMessage(e.getMessage());
    }
                                      
  }
  
  /***********************************************************************/
  /* function private removeNulls(byte[])                                */
  /* Convert null bytes to spaces                                        */
  /***********************************************************************/
  private void removeNulls(byte[] byteArray)
  {
    int i;
    for(i=1; i<=byteArray.length; i++)
    {
        if(byteArray[i-1]==0)
        {
            byteArray[i-1]=64;
        }
    }
  }
 
  /***********************************************************************/
  /* function private setNull(byte[])                                    */
  /* Convert null bytes to spaces                                        */
  /***********************************************************************/
  private void setNull(byte[] byteArray)
  {
    int i;
    for(i=1; i<=byteArray.length; i++)
    {
        {
            byteArray[i-1]=0;
        }
    }
  }    
  /***********************************************************************/
  /* public void actionPerformed(ActionEvent e)                          */
  /* Required method of ActionListener interface                         */
  /***********************************************************************/
  public void actionPerformed(ActionEvent e)
  {
    if(e.getSource()==btnDelete)
    {
        deleteShare();
        model.clear();
        getShares();
    }
    if(e.getSource()==btnAdd)
    {
        addShare();
        model.clear();
        getShares();
    }        
  }

}