import javax.swing.table.*;
import java.util.Vector;

class ShareListModel extends AbstractTableModel 
{
    protected static int NUM_COLUMNS = 3;
    protected static int START_NUM_ROWS = 5;
    protected int nextEmptyRow = 0;
    protected int numRows = 0;

    static final public String szShare = "SHARE";
    static final public String szPath = "PATH";
    static final public String szAccess = "ACCESS";

    protected Vector data = null;

    public ShareListModel() 
    {
        data = new Vector();
    }

    public String getColumnName(int column) 
    {
	switch (column)
	{
	  case 0:
	    return szShare;
	  case 1:
	    return szPath;
	  case 2:
	    return szAccess;
	}
	return "";
    }

    public int getColumnCount() {
        return NUM_COLUMNS;
    }

    public int getRowCount() {
        if (numRows < START_NUM_ROWS) {
            return START_NUM_ROWS;
        } else {
            return numRows;
        }
    }

    public synchronized Object getValueAt(int row, int column) {
	try 
	{
	    FileShare share = (FileShare)data.elementAt(row);
        switch (column) 
        {
            case 0:
                return share.szShare;
            case 1:
                return share.szPath;
            case 2:
                return share.szAccess;
        }    
	} 
	catch (Exception e) 
	{
	}
	return "";
    }

    public void updateShare(FileShare share)
    {
        FileShare s = null;
        int index = -1; 
        boolean found = false;
	    boolean addedRow = false;
        
        int i = 0;
        while (!found && (i < nextEmptyRow)) 
        {
            s = (FileShare)data.elementAt(i);
            if (s.szShare == share.szShare) 
            {
                found = true;
                index = i;
            } 
            else
            {
                i++;
            }
        }

        if (found) 
        { //update old share
	        data.setElementAt(share, index);
        } 
        else 
        { //add share
	        if (numRows <= nextEmptyRow) 
	        {
		        //add a row
                numRows++;
		        addedRow = true;
            }
            index = nextEmptyRow;
	        data.addElement(share);
	    }
    
        nextEmptyRow++;

	    //Notify listeners that the data changed.
	    if (addedRow) 
	    {
	        fireTableRowsInserted(index, index);
	    } 
	    else 
	    {
	        fireTableRowsUpdated(index, index);
	    }
    }

    public synchronized void clear() 
    {
	    int oldNumRows = numRows;

        numRows = START_NUM_ROWS;
	    data.removeAllElements();
        nextEmptyRow = 0;

	    if (oldNumRows > START_NUM_ROWS) 
	    {
    	    fireTableRowsDeleted(START_NUM_ROWS, oldNumRows - 1);
	    }
	
	    fireTableRowsUpdated(0, START_NUM_ROWS - 1);
    }
}
